# Data Transformation Library

## About

This project is an exercise primarily focused on building Python libraries, dependency management using Poetry and publishing packages to PyPI.

The task is to implement three data transformation functions:
* Transpose
* Time Series Windowing
* Cross-Correlation (Convolution)

Functions were built using Python and Numpy (as per requirements of this task).

For package management we were required to use Poetry.

## Libraries Used

For this project only Python's **standard library** as well as **Numpy** (were it was required) were used.

## How to Use

As this project is an exercise on building Python libraries, the library itself must first be installed from PyPI, were it is being published.

To do so in the terminal window type `pip install dtl-functions-rd`. After the library is installed, open the `main.py` file that is located in the main project directory to see a few examples on how to use the functions of this data transformation library.


## Possible Future Improvements

* Version handling